#!/bin/bash

# Packager : Jean-Philippe Guillemin <jp.guillemin@free.fr>




softname='thunar'
#softversion=''
tarball=$(ls ${softname}*tar*);softversion=${tarball%.*};softversion=${softversion%.*}; softversion=${softversion##*-}
packageversion='72.1'
arch='i486'
cpu='i686'

PKGBUILD=$(pwd)

package="$softname-$softversion-$arch-$packageversion"

PKG="/tmp/$package"
rm -rf $PKG
rm -f $PKG.txz
mkdir -p $PKG

TMP="$PKGBUILD/tmp"

cd $PKGBUILD

sources="\
thunar \
volman "


for source in $sources ; do
  echo -n "Checking $source : "
  cd $PKGBUILD
  tarball="$(ls ${source}*tar* 2>/dev/null)"
  if [ "$tarball" == "" ] ; then
    echo "not found :("
    exit 1
  else
    echo "found $tarball :)"
  fi
done

for source in $sources ; do

  cd $PKGBUILD
  tarball="$(ls ${source}*tar* )"

  rm -rf $TMP
  mkdir -p $TMP
  
  if [ "$(echo $tarball | grep ".tar.bz2" )" ]; then
      tar jxvf $tarball -C $TMP
  elif [ "$(echo $tarball | grep ".tar.gz" )" ]; then
      tar zxvf $tarball -C $TMP
  fi
  
  SRC=$(ls -d $TMP/*/)

  
    cd $SRC
EXTRACONFIG="--enable-maintainer-mode"
	#[ "$source" == "thunar" ] && patch -p1 < $PKGBUILD/thunar-1.2.2-gvfs.patch
	#[ "$source" == "thunar" ] && patch -p1 < $PKGBUILD/thunar-1.2.2-gvfs_smb.patch

    chown -R root.root .
    find . -perm 777 -exec chmod 755 {} \;
    find . -perm 775 -exec chmod 755 {} \;
    find . -perm 666 -exec chmod 644 {} \;
    find . -perm 664 -exec chmod 644 {} \;
#./autogen.sh
#make clean
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export ICEAUTH='/usr/bin/iceauth'
EXTRACONFIG="--enable-maintainer-mode"
    ./configure --prefix=/usr \
      --mandir=/usr/man \
      --sysconfdir=/etc \
      --enable-static=no \
      --enable-compositor \
      --enable-xinerama \
      --enable-final \
      --enable-debug=no \
      --with-sound=alsa \
      --disable-gtk-doc \
      $EXTRACONFIG
            
    make -j2 || exit 1
    # make install
    
    make install DESTDIR=$PKG

    mkdir -p $PKG/usr/doc/$(basename $SRC)
    cp -f AUTHORS INSTALL README TODO NEWS ChangeLog $PKG/usr/doc/$(basename $SRC)   

    # Striptease
    ( cd $PKG
      find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
      find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

	  for mandir in $(find ./usr/share/man -name man* -type d) ; do
		mkdir -p ./usr/man/$(basename $mandir)
        mv $mandir/*.? ./usr/man/$(basename $mandir)
      done	  
	  rm -rf ./usr/share/man
	  for mandir in $(find . -name man -type d) ; do
        if [ -d $mandir ]; then
          ( cd $mandir
            find . -type f -name "*.?" -exec gzip -9 {} \;
          )
        fi
      done
    )
done


cd $PKGBUILD

# Thunar custom commands are in the xfce-desktop package
rm -f $PKG/etc/X11/xdg/Thunar/uca.xml

# No more dirty doc
# rm -rf $PKG/usr/share/xfce4/doc
# rm -rf $PKG/usr/share/doc/Thunar
#mkdir -p $PKG/usr/share/xfce4/doc
#mv $PKG/usr/share/doc/Thunar/html $PKG/usr/share/xfce4/doc/Thunar
#(
#cd $PKG/usr/share/xfce4/doc/Thunar
#for dir in $(ls -d *); do 
#  if test -d $dir ; then 
#    mkdir -p $PKG/usr/share/xfce4/doc/${dir}
#  	  (
#  	  cd $PKG/usr/share/xfce4/doc/${dir}
#  	  ln -s ../Thunar/${dir} Thunar
#  	  ln -s ../Thunar/thunar.css thunar.css
#      sed -i 's@xffm\.html@Thunar/index.html@g' index.html
#      )
#  fi
#done
#)

# redundant , if any
# rm -rf $PKG/usr/share/doc

# Some custom icons
# for size in 16x16 22x22 24x24 32x32 48x48 64x64 96x96 128x128 scalable ; do
# 	for category in apps actions status places ; do
# 		[ -e $PKGBUILD/icons/${size}/${category} ] && mkdir -p $PKG/usr/share/icons/hicolor/${size}/${category}
# 		[ -e $PKGBUILD/icons/${size}/${category} ] && cp -f $PKGBUILD/icons/${size}/${category}/*.* $PKG/usr/share/icons/hicolor/${size}/${category}
# 	done
# 	rm -rf $PKG/usr/share/icons/hicolor/${size}/stock
# done

# install udisks permission file
  install -dm700 $PKG/etc/polkit-1/localauthority
  install -dm755 $PKG/etc/polkit-1/localauthority/50-local.d
#  install -m644 $PKG/org.freedesktop.udisks.pkla $PKG/etc/polkit-1/localauthority/50-local.d/

cat > $PKG/etc/polkit-1/localauthority/50-local.d/org.freedesktop.udisks.pkla << END
[Local Users]
#Identity=unix-user: your_username
Identity=unix-group:storage
Action=org.freedesktop.udisks.*
ResultAny=yes
ResultInactive=no
ResultActive=yes
END

# Backward compat
(
cd $PKG/usr/include
ln -sf thunarx-2/thunarx thunarx

cd $PKG/usr/share/pkgconfig
cp thunarx-2.pc thunarx-1.pc

cd $PKG/usr/lib
ln -s libthunarx-2.so.0.0.0 libthunarx-1.so.2
ln -sf thunarx-1 thunarx-2


)

# Fix the Volman launcher
sed -i 's/^Categories.*$/Categories=X-XFCE;Settings;DesktopSettings;X-XfceSettingsDialog;/' \
	$PKG/usr/share/applications/thunar-volman-settings.desktop

# Fix the Thunar sendto helper
sed -i 's@^Exec.*$@Exec=thunderbird -compose "attachment=file://%F"@' \
	$PKG/usr/share/Thunar/sendto/thunar-sendto-email.desktop
	
# slack-desc
mkdir -p $PKG/install
cat > $PKG/install/slack-desc << END
$softname: $softname is part of the XFCE Desktop
$softname:
$softname: XFce is a fast and lightweight desktop environment that is both
$softname: sex-appealing and easy to use.
$softname: 
$softname: For more information, see:  http://www.xfce.org
$softname:
$softname:
$softname:
$softname:
$softname:
END

mkdir -p $PKG/usr/src/$softname-$softversion
cp $PKGBUILD/build-$softname.sh $PKG/usr/src/$softname-$softversion/

 

cd $PKG
makepkg -l y -c n $PKG.txz

# Cleanup
cd $PKGBUILD
rm -rf $PKG
rm -rf $TMP
